﻿using C1.WPF.C1Chart;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WpfApplication31
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {

        ObservableCollection<SampleItem> _items;
        public MainWindow()
        {
            InitializeComponent();
            InitData();
            InitChart();


        }
        private void InitData()
        {
            Random rnd = new Random();
            _items = new ObservableCollection<SampleItem>();
            for (int i = 0; i < 3; i++)
            {
                _items.Add(new SampleItem { Value = rnd.Next(0, 100), Date = DateTime.Now.AddMonths(i) });
            }
        }

        private void InitChart()
        {
            // configure data series
            var ds = new XYDataSeries()
            {
                ItemsSource = _items,
                ValueBinding = new Binding { Path = new PropertyPath("Value") },
                XValueBinding = new Binding { Path = new PropertyPath("Date") },
                Label = "Sales"
            };

            // configure chart
            c1Chart1.BeginUpdate();
            c1Chart1.ChartType = ChartType.Column;

            // add data series
            c1Chart1.Data.Children.Add(ds);

            // use time axis with specific formatting
            c1Chart1.View.AxisX.IsTime = true;
            c1Chart1.View.AxisX.AnnoFormat = "yyyy/MM";

            //Tooltip
            var pnl = new ChartPanel();
            var obj = new ChartPanelObject()
            {
                HorizontalAlignment = HorizontalAlignment.Right,
                VerticalAlignment = VerticalAlignment.Bottom
            };

            var bdr = new Border()
            {
                Background = new SolidColorBrush(Colors.Green) { Opacity = 0.4 },
                BorderBrush = new SolidColorBrush(Colors.Green),
                BorderThickness = new Thickness(1, 1, 3, 3),
                CornerRadius = new CornerRadius(6, 6, 0, 6),
                Padding = new Thickness(3)
            };

            var sp = new StackPanel();
            var tb1 = new TextBlock();
            var bind1 = new Binding();
            bind1.Source = obj;
            bind1.StringFormat = "x={0:yyyy/MM/dd}";
            bind1.Converter = new DateTimeConverter();
            bind1.Path = new PropertyPath("DataPoint.X");
            tb1.SetBinding(TextBlock.TextProperty, bind1);

            var tb2 = new TextBlock();
            var bind2 = new Binding();
            bind2.Source = obj;
            bind2.StringFormat = "y={0:#.##}";
            bind2.Path = new PropertyPath("DataPoint.Y");
            tb2.SetBinding(TextBlock.TextProperty, bind2);

            sp.Children.Add(tb1);
            sp.Children.Add(tb2);

            bdr.Child = sp;

            obj.Content = bdr;
            obj.DataPoint = new Point();
            obj.Action = ChartPanelAction.MouseMove;
            pnl.Children.Add(obj);

            c1Chart1.View.Layers.Add(pnl);
            obj.Action = ChartPanelAction.MouseMove;


            c1Chart1.EndUpdate();
        }

    }
    public class SampleItem
    {
        public double Value { get; set; }
        public DateTime Date { get; set; }
    }

    public class DateTimeConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            double v = (double)value;
            DateTime dt;
            if (!double.IsNaN(v))
            {
                dt = DateTime.FromOADate(v);
            }
            else
            {
                dt = DateTime.Now;
            }
            return dt;
        

        }



        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {

            throw new NotImplementedException();

        }

    }

}
